@@ -94,7 +94,14 @@ module FILEUTILS
   def cp_r( from, to )
     if directory? from then
       from = File.expand_path(from)
-      do_cp_r File.dirname(from), File.basename(from), to
+			to = File.expand_path(to)
+			unless File.directory? to then
+			  if File.exist? to then
+				  rm_f to
+				end
+			  mkdir to
+			end
+      do_cp_r from, '.', to
     else
       cp from, to
     end
